..
      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

OVN Octavia Provider Driver
===========================

OVN provides virtual networking for Open vSwitch and is a component of the Open
vSwitch project. This project provides integration between OpenStack Octavia
and OVN.

Default provider name: **ovn**

The driver package: https://pypi.org/project/ovn-octavia-provider/

The driver source: https://opendev.org/openstack/ovn-octavia-provider

The documentation: https://docs.openstack.org/ovn-octavia-provider/latest/

Where to report issues with the driver: https://bugs.launchpad.net/neutron/+bugs?field.tag=ovn-octavia-provider
